@@ -146,6 +146,17 @@ def to_designspace_axes(self):
         axis.name = axis_def.name
         # TODO add support for localised axis.labelNames when Glyphs.app does
 
+        # Make sure here that if there is an Axes parameter, we actually really
+        # keep axes that are defined in it, even if they do nothing. This
+        # prevents an edge case where you have a single master at the default
+        # location that ends in with a Designspace with no axes, as they were
+        # all filtered out by the `if` statement at the bottom.
+        axis_wanted = False
+        if any(
+            a.get("Tag") == axis.tag for a in self.font.customParameters["Axes"] or []
+        ):
+            axis_wanted = True
+
         # See https://github.com/googlefonts/glyphsLib/issues/280
         if font_uses_new_axes(self.font):
             # Build the mapping from the "Axis Location" of the masters
@@ -206,6 +217,7 @@ def to_designspace_axes(self):
             minimum < maximum
             or minimum != axis_def.default_user_loc
             or not is_identity_map
+            or axis_wanted
         ):
             if not is_identity_map:
                 axis.map = sorted(mapping.items())
@@ -214,6 +226,21 @@ def to_designspace_axes(self):
             axis.default = default
             self.designspace.addAxis(axis)
 
+    # If there are no interesting axes, but only a single master at default location
+    # along all 3 predefined axes, all with identity user:design mapping, we end up
+    # with an empty list of axes, which is invalid. Thus as last resort we emit a
+    # do-nothing Weight axis (the default axis when no "Axes" custom parameter is
+    # defined) where default==min==max==400.
+    # https://github.com/googlefonts/fontmake/issues/644
+    if not self.designspace.axes:
+        self.designspace.addAxisDescriptor(
+            name=WEIGHT_AXIS_DEF.name,
+            tag=WEIGHT_AXIS_DEF.tag,
+            minimum=WEIGHT_AXIS_DEF.default_user_loc,
+            default=WEIGHT_AXIS_DEF.default_user_loc,
+            maximum=WEIGHT_AXIS_DEF.default_user_loc,
+        )
+
 
 def font_uses_new_axes(font):
     # It's possible for fonts to have the 'Axes' parameter but to NOT specify
