@@ -19,6 +19,7 @@ import logging
 import os
 import re
 from textwrap import dedent
+from typing import Dict
 
 from fontTools import designspaceLib
 
@@ -117,6 +118,10 @@ class UFOBuilder(_LoggerMixin):
         # indexed by master ID, the same order as masters in the source GSFont.
         self._sources = OrderedDict()
 
+        # A cache for mappings of layer IDs to mappings of glyph names to Glyphs layers,
+        # for passing into pens as glyph sets.
+        self._glyph_sets: Dict[str, Dict[str, classes.GSLayer]] = {}
+
         # The designSpaceDocument object that will be built.
         # The sources will be built in any case, at the same time that we build
         # the master UFOs, when the user requests them.
